# Copyright Notice
# ================
# 
# ----------------------------------------------------------------------
#
############################################################################
#
# This SwisssideChain plugin is copyright of the Swiss Institute of Bioinformatics. 
# There are no restriction on its use by non-profit institutions as long as its 
# content is in no way modified and this statement is not removed. 
#
# Usage by and for commercial entities requires a license agreement 
# (see our legal disclaimer on http://www.swisssidechain.ch/license.html
# or send email to license@genebio.com).
#
# For scientific questions, please contact David Gfeller (david.gfeller@isb-sib.ch)
#
############################################################################


######### Usage ###########
#
# Command-line: Mutate 'chain'/'residue#'/, 'newres', e.g: Mutate A/2/, ARG
# If more than one object are loaded:  Mutate 'object'//'chain'/'residue#'/, 'newres', e.g: Mutate 1BFE//A/2/, ARG
#
#########################

from __future__ import print_function
from __future__ import absolute_import

import sys
if sys.version_info[0] < 3:
    import tkSimpleDialog
else:
    from tkinter import simpledialog as tkSimpleDialog

from pymol import cmd


def __init__(self):
   
    self.menuBar.addmenuitem('Plugin', 'command', 'Mutate', label='PySwissSidechain...', command = lambda s=self : Mutate(s))
    self.menuBar.addmenuitem('Plugin', 'command', 'Mutate', label='PySwissSidechain install fragments', command = lambda: install_fragments())

def install_fragments():
    '''
    Copy all fragment files to PyMOL's "chempy/fragments/" folder, so that
    they work with the cmd.fragment() function.
    '''
    import os
    import shutil
    import glob
    import chempy.fragments

    try:
        if not os.path.isdir(chempy.fragments.path):
            raise UserWarning('directory chempy.fragments.path missing')

        for filename in glob.glob(os.path.join(os.path.dirname(__file__), 'fragments', '*.pkl')):
            shutil.copy(filename, chempy.fragments.path)

        print('Fragments installation completed')
    except Exception as e:
        print('Error: ' + str(e))

def MutateExecute(selection='', mutant=''):
    '''
DESCRIPTION

    Opens the SwissSidechain mutagenesis wizard
    '''
    from .mutagenesis1 import Mutagenesis1

    wiz = Mutagenesis1()
    cmd.set_wizard(wiz)

    if selection:
        wiz.do_select(selection)

    if mutant:
        wiz.set_mode(mutant)

def Mutate(app):
    
    sel=tkSimpleDialog.askstring('PySwissSidechain', 'Please enter the residue you want to mutate:', parent=app.root)

    mut=tkSimpleDialog.askstring('PySwissSidechain', 'Please enter the SwissSidechain code of the new residue:', parent=app.root)

    MutateExecute(sel, mut)


cmd.extend("Mutate", MutateExecute)
